@@ -1,12 +1,19 @@
 import getpass
+import hashlib
 import logging
 import os
 import sys
 from pathlib import Path, PurePosixPath, PureWindowsPath
 from typing import Any, Generator, Protocol, Union
 
+import dotenv
 from fabric import Connection
 
+from shareplum import Site
+from shareplum import Office365
+from shareplum.site import Version
+from shareplum.errors import ShareplumRequestError
+
 from oeleo.filters import base_filter
 from oeleo.movers import simple_mover
 from oeleo.utils import calculate_checksum
@@ -17,13 +24,19 @@ FabricRunResult = Any
 Hash = str
 
 
-class Connector(Protocol):
-    """Connectors are used to establish a connection to the server and
-    provide the functions and methods needed for the movers and checkers.
+def register_password(pwd: str = None) -> None:
+    """Helper function to export the password as an environmental variable"""
+    log.debug(" -> Register password ")
+    if pwd is None:
+        # Consider replacing this with the Rich prompt.
+        session_password = getpass.getpass(prompt="Password: ")
+        os.environ["OELEO_PASSWORD"] = session_password
+    log.debug(" Password registered!")
 
-    Connectors are typically only needed for transactions between computers.
-    If no connector is given to the oeleo worker, the worker will use the
-    same methods for local and external files.
+
+class Connector(Protocol):
+    """Connectors are used to establish a connection to the directory and
+    provide the functions and methods needed for the movers and checkers.
     """
 
     directory = None
@@ -195,10 +208,106 @@ class SSHConnector(Connector):
         return True
 
 
-def register_password(pwd: str = None) -> None:
-    log.debug(" -> Register password ")
-    if pwd is None:
+class SharePointConnection:
+    def __init__(self, url, site_name, username, password, doc_library):
+        self.site_url = "/".join([url, "sites", site_name])
+        self.authcookie = Office365(
+            url, username=username, password=password
+        ).GetCookies()
 
-        session_password = getpass.getpass(prompt="Password: ")
-        os.environ["OELEO_PASSWORD"] = session_password
-    log.debug(" Password registered!")
+        self.site = Site(
+            self.site_url, version=Version.v365, authcookie=self.authcookie
+        )
+        self.folder = self.site.Folder(doc_library)
+
+    @staticmethod
+    def close(self):
+        pass
+
+
+class SharePointConnector(Connector):
+    def __init__(
+        self,
+        username=None,
+        host=None,
+        url=None,
+        directory=None,
+    ):
+        self.username = username or os.environ["OELEO_USERNAME"]
+        self.session_password = os.environ["OELEO_PASSWORD"]
+        self.url = url or os.environ["OELEO_SHAREPOINT_URL"]
+
+        self.site_name = host or os.environ["OELEO_SHAREPOINT_SITENAME"]
+        self.directory = directory or os.environ["OELEO_SHAREPOINT_DOC_LIBRARY"]
+        self.connection = None
+
+    def __str__(self):
+        text = "SharePointConnector"
+        text += f"{self.username=}\n"
+        text += f"{self.url=}\n"
+        text += f"{self.site_name=}\n"
+        text += f"{self.directory=}\n"
+        text += f"{self.connection=}\n"
+
+        return text
+
+    def __delete__(self, instance):
+        if self.connection is not None:
+            self.connection.close()
+
+    def connect(self, **kwargs) -> None:
+        self.connection = SharePointConnection(
+            url=self.url,
+            site_name=self.site_name,
+            username=self.username,
+            password=self.session_password,
+            doc_library=self.directory,
+        )
+
+    def close(self):
+        self.connection.close()
+
+    def base_filter_sub_method(
+        self, glob_pattern: str = "", **kwargs: Any
+    ) -> Generator[Path, None, None]:
+        file_list = []
+        request = self.connection.folder.files
+        for f in request:
+            filename = f.get("Name", "")
+            if filename and glob_pattern in filename:
+                file_list.append(Path(filename))
+        return file_list
+
+    def calculate_checksum(self, f: Path, hide=True):
+        try:
+            b = self.connection.folder.get_file(f.name)
+
+        except ShareplumRequestError:
+            return False
+
+        file_hash = hashlib.md5(b)
+        return file_hash.hexdigest()
+
+    def move_func(self, path: Path, to: Path, *args, **kwargs) -> bool:
+        try:
+            log.debug(f"Copying {path} to {to}")
+            file_content = path.read_bytes()
+            self.connection.folder.upload_file(file_content, path.name)
+
+        except ShareplumRequestError as e:
+            log.debug("GOT A ShareplumRequestError EXCEPTION DURING COPYING FILE")
+            log.debug(f"FROM     : {path}")
+            log.debug(f"TO       : {to}")
+            log.debug(f"EXCEPTION:")
+            log.debug(e)
+            return False
+
+        except Exception as e:
+            log.debug("GOT AN EXCEPTION DURING COPYING FILE")
+            log.debug(f"FROM     : {path}")
+            log.debug(f"TO       : {to}")
+            log.debug(f"EXCEPTION:")
+            log.debug(e)
+            return False
+
+        return True
